absorbing_centrality.compute_personalized_transition_matrix
===========================================================

.. currentmodule:: absorbing_centrality

.. autofunction:: compute_personalized_transition_matrix